@@ -3,7 +3,8 @@
 """
 
 import datetime
-from typing import List, Union
+import re
+from typing import List, Optional, Union
 
 import dateutil.parser
 import dateutil.relativedelta as rdelta
@@ -310,9 +311,13 @@ class DateTimeRange:
 
         return self.is_set()
 
-    def is_intersection(self, x):
+    def is_intersection(self, x, intersection_threshold=None):
         """
         :param DateTimeRange x: Value to compare
+        :param Optional[datetime.timedelta] intersection_threshold:
+            Minimum time constraint that an intersection must have.
+            Defaults to ``None`` (no constraint).
+
         :return: |True| if intersect with ``x``
         :rtype: bool
 
@@ -329,7 +334,7 @@ class DateTimeRange:
                 True
         """
 
-        return self.intersection(x).is_set()
+        return self.intersection(x, intersection_threshold).is_set()
 
     def get_start_time_str(self):
         """
@@ -568,25 +573,33 @@ class DateTimeRange:
         except ValueError:
             is_inversion = True
 
+        current_datetime = self.start_datetime
+
         if not is_inversion:
             if self.__compare_timedelta(step, seconds=0) < 0:
                 raise ValueError(f"invalid step: expect greater than 0, actual={step}")
+
+            while current_datetime <= self.end_datetime:
+                yield current_datetime
+                current_datetime = current_datetime + step
         else:
             if self.__compare_timedelta(step, seconds=0) > 0:
                 raise ValueError(f"invalid step: expect less than 0, actual={step}")
 
-        current_datetime = self.start_datetime
-        while current_datetime <= self.end_datetime:
-            yield current_datetime
-            current_datetime = current_datetime + step
+            while current_datetime >= self.end_datetime:
+                yield current_datetime
+                current_datetime = current_datetime + step
 
-    def intersection(self, x):
+    def intersection(self, x, intersection_threshold=None):
         """
-        Newly set a time range that overlaps
-        the input and the current time range.
+        Create a new time range that overlaps the input and the current time range.
+        If no overlaps found, return a time range that set ``None`` for both start and end time.
 
         :param DateTimeRange x:
             Value to compute intersection with the current time range.
+        :param Optional[datetime.timedelta] intersection_threshold:
+            Minimum time constraint that an intersection must have.
+            Defaults to ``None`` (no constraint).
 
         :Sample Code:
             .. code:: python
@@ -611,6 +624,12 @@ class DateTimeRange:
             start_datetime = None
             end_datetime = None
 
+        if intersection_threshold is not None:
+            delta = end_datetime - start_datetime
+            if delta < intersection_threshold:
+                start_datetime = None
+                end_datetime = None
+
         return DateTimeRange(
             start_datetime=start_datetime,
             end_datetime=end_datetime,
@@ -703,8 +722,7 @@ class DateTimeRange:
 
     def encompass(self, x):
         """
-        Newly set a time range that encompasses
-        the input and the current time range.
+        Create a new time range that encompasses the input and the current time range.
 
         :param DateTimeRange x:
             Value to compute encompass with the current time range.
@@ -830,3 +848,42 @@ class DateTimeRange:
             ).convert()
         except typepy.TypeConversionError as e:
             raise ValueError(e)
+
+    @classmethod
+    def from_range_text(
+        cls,
+        range_text: str,
+        separator: str = r"\s+\-\s+",
+        start_time_format: Optional[str] = None,
+        end_time_format: Optional[str] = None,
+    ) -> "DateTimeRange":
+        """Create a ``DateTimeRange`` instance from a datetime range text.
+
+        :param str range_text:
+            Input text that includes datetime range.
+            e.g. ``2021-01-23T10:00:00+0400 - 2021-01-232T10:10:00+0400``
+
+        :param str separator:
+            Regular expression that separating the ``range_text`` to start and end time.
+
+        :return: DateTimeRange
+            Created instance.
+        """
+
+        datetime_ranges = re.split(separator, range_text.strip())
+        if len(datetime_ranges) != 2:
+            raise ValueError(
+                f"range_text should include two datetime that separated by hyphen: got={datetime_ranges}"
+            )
+
+        start, end = datetime_ranges
+        kwargs = {
+            "start_datetime": start,
+            "end_datetime": end,
+        }
+        if start_time_format:
+            kwargs["start_time_format"] = start_time_format
+        if end_time_format:
+            kwargs["end_time_format"] = end_time_format
+
+        return DateTimeRange(**kwargs)
