@@ -604,7 +604,9 @@ class TestDateTimeRange_range:
         ],
     )
     def test_normal(self, value, step, expected):
-        for value_item, expected_item in zip(value.range(step), expected):
+        results = list(value.range(step))
+        assert len(results) == len(expected)
+        for value_item, expected_item in zip(results, expected):
             assert value_item == expected_item
 
     @pytest.mark.parametrize(
@@ -699,6 +701,35 @@ class TestDateTimeRange_is_intersection:
     def test_normal(self, lhs, rhs, expected):
         assert lhs.is_intersection(rhs) == expected
 
+    @pytest.mark.parametrize(
+        ["lhs", "rhs", "threshold", "expected"],
+        [
+            [
+                DateTimeRange("2015-01-22T09:50:00 JST", "2015-01-22T10:00:00 JST"),
+                DateTimeRange("2015-01-22T10:00:00 JST", "2015-03-22T10:20:00 JST"),
+                timedelta(seconds=0),
+                True,
+            ],
+            [
+                DateTimeRange("2015-01-22T09:50:00 JST", "2015-01-22T10:00:00 JST"),
+                DateTimeRange("2015-01-22T10:00:00 JST", "2015-03-22T10:20:00 JST"),
+                timedelta(seconds=1),
+                False,
+            ],
+            [
+                DateTimeRange("2015-01-22T09:50:00 JST", "2015-01-22T10:00:01 JST"),
+                DateTimeRange("2015-01-22T10:00:00 JST", "2015-03-22T10:20:00 JST"),
+                timedelta(seconds=1),
+                True,
+            ],
+        ],
+    )
+    def test_normal_w_intersection_threshold(self, lhs, rhs, threshold, expected):
+        lhs_org = deepcopy(lhs)
+
+        assert lhs.is_intersection(rhs, threshold) == expected
+        assert lhs == lhs_org
+
     @pytest.mark.parametrize(
         ["lhs", "rhs", "expected"],
         [
@@ -1021,6 +1052,35 @@ class TestDateTimeRange_intersection:
         assert lhs.intersection(rhs) == expected
         assert lhs == lhs_org
 
+    @pytest.mark.parametrize(
+        ["lhs", "rhs", "threshold", "expected"],
+        [
+            [
+                DateTimeRange("2015-01-22T09:50:00 JST", "2015-01-22T10:00:00 JST"),
+                DateTimeRange("2015-01-22T10:00:00 JST", "2015-03-22T10:20:00 JST"),
+                timedelta(seconds=0),
+                DateTimeRange("2015-01-22T10:00:00 JST", "2015-01-22T10:00:00 JST"),
+            ],
+            [
+                DateTimeRange("2015-01-22T09:50:00 JST", "2015-01-22T10:00:00 JST"),
+                DateTimeRange("2015-01-22T10:00:00 JST", "2015-03-22T10:20:00 JST"),
+                timedelta(seconds=1),
+                DateTimeRange(None, None),
+            ],
+            [
+                DateTimeRange("2015-01-22T09:50:00 JST", "2015-01-22T10:00:01 JST"),
+                DateTimeRange("2015-01-22T10:00:00 JST", "2015-03-22T10:20:00 JST"),
+                timedelta(seconds=1),
+                DateTimeRange("2015-01-22T10:00:00 JST", "2015-01-22T10:00:01 JST"),
+            ],
+        ],
+    )
+    def test_normal_w_intersection_threshold(self, lhs, rhs, threshold, expected):
+        lhs_org = deepcopy(lhs)
+
+        assert lhs.intersection(rhs, threshold) == expected
+        assert lhs == lhs_org
+
     @pytest.mark.parametrize(
         ["lhs", "rhs", "expected"],
         [
@@ -1174,3 +1234,54 @@ class TestDateTimeRange_split:
     )
     def test_normal(self, dtr, separator, expected):
         assert dtr.split(separator) == expected
+
+
+class TestDateTimeRange_from_range_text:
+    @pytest.mark.parametrize(
+        ["value", "separator", "expected"],
+        [
+            [
+                f"{START_DATETIME_TEXT} - {END_DATETIME_TEXT}",
+                r"\s+\-\s+",
+                DateTimeRange(START_DATETIME_TEXT, END_DATETIME_TEXT),
+            ],
+            [
+                f"{START_DATETIME_TEXT} to {END_DATETIME_TEXT}",
+                "to",
+                DateTimeRange(START_DATETIME_TEXT, END_DATETIME_TEXT),
+            ],
+            [
+                f"{START_DATETIME_TEXT}  -  {END_DATETIME_TEXT}",
+                r"\s+\-\s+",
+                DateTimeRange(START_DATETIME_TEXT, END_DATETIME_TEXT),
+            ],
+        ],
+    )
+    def test_normal(self, value, separator, expected):
+        dtr = DateTimeRange.from_range_text(value, separator=separator)
+        assert dtr == expected
+        assert dtr.start_time_format == r"%Y-%m-%dT%H:%M:%S%z"
+        assert dtr.end_time_format == r"%Y-%m-%dT%H:%M:%S%z"
+
+    @pytest.mark.parametrize(
+        ["value", "time_format", "expected"],
+        [
+            [
+                f"{START_DATETIME_TEXT} - {END_DATETIME_TEXT}",
+                r"%Y-%m-%d",
+                DateTimeRange(
+                    START_DATETIME_TEXT,
+                    END_DATETIME_TEXT,
+                    start_time_format=r"%Y-%m-%d",
+                    end_time_format=r"%Y-%m-%d",
+                ),
+            ],
+        ],
+    )
+    def test_normal_time_format(self, value, time_format, expected):
+        dtr = DateTimeRange.from_range_text(
+            value, start_time_format=time_format, end_time_format=time_format
+        )
+        assert dtr == expected
+        assert dtr.start_time_format == time_format
+        assert dtr.end_time_format == time_format
